pub enum Category {
Correctness,
Suspicious,
Style,
Complexity,
Perf,
Pedantic,
Restriction,
Portability,
Introspection,
}Expand description
Rule category (similar to Clippy’s lint categories)
Variants
Correctness
Code that is outright wrong or very useless
Suspicious
Code that is most likely wrong or useless
Style
Code that should be written in a more idiomatic way
Complexity
Code that does something simple but in a complex way
Perf
Code that can be written to run faster
Pedantic
Lints which are rather strict or have occasional false positives
Restriction
Lints which prevent the use of language/library features
Portability
Code that may cause portability issues across platforms/compilers
Introspection
GObject Introspection annotation issues
Implementations